datastructuretools.CyclicList
=============================

.. abjad-lineage:: abjad.tools.datastructuretools.CyclicList.CyclicList

.. autoclass:: abjad.tools.datastructuretools.CyclicList.CyclicList

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.CyclicList.CyclicList.append
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.count
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.extend
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.index
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.insert
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.pop
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.remove
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.reverse
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.sort
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__add__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__contains__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__delitem__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__delslice__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__eq__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__format__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__ge__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__getitem__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__getslice__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__gt__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__iadd__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__imul__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__iter__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__le__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__len__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__lt__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__mul__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__ne__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__repr__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__reversed__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__rmul__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__setitem__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__setslice__
      ~abjad.tools.datastructuretools.CyclicList.CyclicList.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.list <list>`

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.append
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.count
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.extend
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.index
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.insert
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.pop
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.remove
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.reverse
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__add__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__contains__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__delitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__delslice__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__format__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__ge__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__getitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__getslice__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__gt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__iadd__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__imul__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__iter__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__le__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__len__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__lt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__mul__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__repr__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__reversed__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__rmul__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__setitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__setslice__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.CyclicList.CyclicList.__str__
   :noindex:
